@@ -3,7 +3,7 @@ from .batch import Batch
 from .dataset import Dataset
 from .in_memory_dataset import InMemoryDataset
 from .dataloader import DataLoader, DataListLoader, DenseDataLoader
-from .sampler import NeighborSampler
+from .sampler import NeighborSampler, RandomNodeSampler
 from .cluster import ClusterData, ClusterLoader
 from .graph_saint import (GraphSAINTSampler, GraphSAINTNodeSampler,
                           GraphSAINTEdgeSampler, GraphSAINTRandomWalkSampler)
@@ -19,6 +19,7 @@ __all__ = [
     'DataListLoader',
     'DenseDataLoader',
     'NeighborSampler',
+    'RandomNodeSampler',
     'ClusterData',
     'ClusterLoader',
     'GraphSAINTSampler',
