@@ -15,12 +15,19 @@ class Batch(Data):
     def __init__(self, batch=None, **kwargs):
         super(Batch, self).__init__(**kwargs)
 
+        for key, item in kwargs.items():
+            if key == 'num_nodes':
+                self.__num_nodes__ = item
+            else:
+                self[key] = item
+
         self.batch = batch
         self.__data_class__ = Data
         self.__slices__ = None
         self.__cumsum__ = None
         self.__cat_dims__ = None
         self.__num_nodes_list__ = None
+        self.__num_graphs__ = None
 
     @staticmethod
     def from_data_list(data_list, follow_batch=[]):
@@ -35,10 +42,16 @@ class Batch(Data):
         assert 'batch' not in keys
 
         batch = Batch()
+        for key in data_list[0].__dict__.keys():
+            if key[:2] != '__' and key[-2:] != '__':
+                batch[key] = None
+
+        batch.__num_graphs__ = len(data_list)
         batch.__data_class__ = data_list[0].__class__
         for key in keys + ['batch']:
             batch[key] = []
 
+        device = None
         slices = {key: [0] for key in keys}
         cumsum = {key: [0] for key in keys}
         cat_dims = {}
@@ -50,11 +63,13 @@ class Batch(Data):
                 # Increase values by `cumsum` value.
                 cum = cumsum[key][-1]
                 if isinstance(item, Tensor) and item.dtype != torch.bool:
-                    item = item + cum if cum != 0 else item
+                    if not isinstance(cum, int) or cum != 0:
+                        item = item + cum
                 elif isinstance(item, SparseTensor):
                     value = item.storage.value()
                     if value is not None and value.dtype != torch.bool:
-                        value = value + cum if cum != 0 else value
+                        if not isinstance(cum, int) or cum != 0:
+                            value = value + cum
                         item = item.set_value(value, layout='coo')
                 elif isinstance(item, (int, float)):
                     item = item + cum
@@ -71,8 +86,10 @@ class Batch(Data):
                 cat_dims[key] = cat_dim
                 if isinstance(item, Tensor):
                     size = item.size(cat_dim)
+                    device = item.device
                 elif isinstance(item, SparseTensor):
                     size = torch.tensor(item.sizes())[torch.tensor(cat_dim)]
+                    device = item.device()
 
                 slices[key].append(size + slices[key][-1])
                 inc = data.__inc__(key, item)
@@ -86,12 +103,14 @@ class Batch(Data):
                             tmp = f'{key}_{j}_batch'
                             batch[tmp] = [] if i == 0 else batch[tmp]
                             batch[tmp].append(
-                                torch.full((size, ), i, dtype=torch.long))
+                                torch.full((size, ), i, dtype=torch.long,
+                                           device=device))
                     else:
                         tmp = f'{key}_batch'
                         batch[tmp] = [] if i == 0 else batch[tmp]
                         batch[tmp].append(
-                            torch.full((size, ), i, dtype=torch.long))
+                            torch.full((size, ), i, dtype=torch.long,
+                                       device=device))
 
             if hasattr(data, '__num_nodes__'):
                 num_nodes_list.append(data.__num_nodes__)
@@ -100,7 +119,8 @@ class Batch(Data):
 
             num_nodes = data.num_nodes
             if num_nodes is not None:
-                item = torch.full((num_nodes, ), i, dtype=torch.long)
+                item = torch.full((num_nodes, ), i, dtype=torch.long,
+                                  device=device)
                 batch.batch.append(item)
 
         # Fix initial slice values:
@@ -165,11 +185,13 @@ class Batch(Data):
                 # Decrease its value by `cumsum` value:
                 cum = self.__cumsum__[key][i]
                 if isinstance(item, Tensor):
-                    item = item - cum if cum != 0 else item
+                    if not isinstance(cum, int) or cum != 0:
+                        item = item - cum
                 elif isinstance(item, SparseTensor):
                     value = item.storage.value()
                     if value is not None and value.dtype != torch.bool:
-                        value = value - cum if cum != 0 else value
+                        if not isinstance(cum, int) or cum != 0:
+                            value = value - cum
                         item = item.set_value(value, layout='coo')
                 elif isinstance(item, (int, float)):
                     item = item - cum
@@ -186,4 +208,6 @@ class Batch(Data):
     @property
     def num_graphs(self):
         """Returns the number of graphs in the batch."""
+        if self.__num_graphs__ is not None:
+            return self.__num_graphs__
         return self.batch[-1].item() + 1
