@@ -9,13 +9,13 @@ from .makedirs import makedirs
 
 
 def to_list(x):
-    if not isinstance(x, (tuple, list)) or isinstance(x, str):
+    if not isinstance(x, (tuple, list)):
         x = [x]
     return x
 
 
 def files_exist(files):
-    return len(files) != 0 and all([osp.exists(f) for f in files])
+    return len(files) != 0 and all(osp.exists(f) for f in files)
 
 
 def __repr__(obj):
@@ -201,7 +201,8 @@ class Dataset(torch.utils.data.Dataset):
                     idx = idx.unsqueeze(0)
                 return self.index_select(idx.tolist())
             elif idx.dtype == torch.bool or idx.dtype == torch.uint8:
-                return self.index_select(idx.nonzero().flatten().tolist())
+                return self.index_select(
+                    idx.nonzero(as_tuple=False).flatten().tolist())
         elif isinstance(idx, list) or isinstance(idx, tuple):
             indices = [indices[i] for i in idx]
         else:
