@@ -38,6 +38,10 @@ from .suite_sparse import SuiteSparseMatrixCollection
 from .particle import TrackMLParticleTrackingDataset
 from .aminer import AMiner
 from .word_net import WordNet18
+from .wikics import WikiCS
+from .webkb import WebKB
+from .wikipedia_network import WikipediaNetwork
+from .actor import Actor
 
 __all__ = [
     'KarateClub',
@@ -81,4 +85,10 @@ __all__ = [
     'TrackMLParticleTrackingDataset',
     'AMiner',
     'WordNet18',
+    'WikiCS',
+    'WebKB',
+    'WikipediaNetwork',
+    'Actor',
 ]
+
+classes = __all__
