@@ -115,7 +115,7 @@ class QM9(InMemoryDataset):
             final dataset. (default: :obj:`None`)
     """  # noqa: E501
 
-    raw_url = ('https://s3-us-west-1.amazonaws.com/deepchem.io/datasets/'
+    raw_url = ('https://deepchemdata.s3-us-west-1.amazonaws.com/datasets/'
                'molnet_publish/qm9.zip')
     raw_url2 = 'https://ndownloader.figshare.com/files/3195404'
     processed_url = 'https://pytorch-geometric.com/datasets/qm9_v2.zip'
@@ -197,7 +197,6 @@ class QM9(InMemoryDataset):
 
         with open(self.raw_paths[2], 'r') as f:
             skip = [int(x.split()[0]) for x in f.read().split('\n')[9:-2]]
-        assert len(skip) == 3054
 
         suppl = Chem.SDMolSupplier(self.raw_paths[0], removeHs=False,
                                    sanitize=False)
@@ -239,8 +238,8 @@ class QM9(InMemoryDataset):
                 edge_type += 2 * [self.bonds[bond.GetBondType()]]
 
             edge_index = torch.tensor([row, col], dtype=torch.long)
-            edge_type = torch.tensor(edge_type)
-            edge_attr = F.one_hot(torch.tensor(edge_type),
+            edge_type = torch.tensor(edge_type, dtype=torch.long)
+            edge_attr = F.one_hot(edge_type,
                                   num_classes=len(self.bonds)).to(torch.float)
 
             perm = (edge_index[0] * N + edge_index[1]).argsort()
@@ -270,5 +269,4 @@ class QM9(InMemoryDataset):
 
             data_list.append(data)
 
-        assert len(data_list) == 130831
         torch.save(self.collate(data_list), self.processed_paths[0])
