@@ -10,9 +10,9 @@ def yield_file(in_file):
         if b.startswith('v '):
             yield ['v', [float(x) for x in b.split(" ")[1:]]]
         elif b.startswith('f '):
-            triangle = b.split(' ')[1:]
+            triangles = b.split(' ')[1:]
             # -1 as .obj is base 1 but the Data class expects base 0 indices
-            yield ['f', [[int(i) - 1 for i in t.split("/")] for t in triangle]]
+            yield ['f', [int(t.split("/")[0]) - 1 for t in triangles]]
         else:
             yield ['', ""]
 
@@ -25,8 +25,7 @@ def read_obj(in_file):
         if k == 'v':
             vertices.append(v)
         elif k == 'f':
-            for i in v:
-                faces.append(i)
+            faces.append(v)
 
     if not len(faces) or not len(vertices):
         return None
