@@ -212,6 +212,8 @@ class DNAConv(MessagePassing):
             cached version for further executions.
             This parameter should only be set to :obj:`True` in transductive
             learning scenarios. (default: :obj:`False`)
+        normalize (bool, optional): Whether to add self-loops and apply
+            symmetric normalization. (default: :obj:`True`)
         add_self_loops (bool, optional): If set to :obj:`False`, will not add
             self-loops to the input graph. (default: :obj:`True`)
         bias (bool, optional): If set to :obj:`False`, the layer will not learn
@@ -225,11 +227,14 @@ class DNAConv(MessagePassing):
 
     def __init__(self, channels: int, heads: int = 1, groups: int = 1,
                  dropout: float = 0., cached: bool = False,
-                 add_self_loops: bool = True, bias: bool = True, **kwargs):
-        super(DNAConv, self).__init__(aggr='add', node_dim=0, **kwargs)
+                 normalize: bool = True, add_self_loops: bool = True,
+                 bias: bool = True, **kwargs):
+        kwargs.setdefault('aggr', 'add')
+        super(DNAConv, self).__init__(node_dim=0, **kwargs)
 
         self.bias = bias
         self.cached = cached
+        self.normalize = normalize
         self.add_self_loops = add_self_loops
 
         self._cached_edge_index = None
@@ -256,27 +261,28 @@ class DNAConv(MessagePassing):
             raise ValueError('Feature shape must be [num_nodes, num_layers, '
                              'channels].')
 
-        if isinstance(edge_index, Tensor):
-            cache = self._cached_edge_index
-            if cache is None:
-                edge_index, edge_weight = gcn_norm(  # yapf: disable
-                    edge_index, edge_weight, x.size(self.node_dim), False,
-                    self.add_self_loops, dtype=x.dtype)
-                if self.cached:
-                    self._cached_edge_index = (edge_index, edge_weight)
-            else:
-                edge_index, edge_weight = cache[0], cache[1]
+        if self.normalize:
+            if isinstance(edge_index, Tensor):
+                cache = self._cached_edge_index
+                if cache is None:
+                    edge_index, edge_weight = gcn_norm(  # yapf: disable
+                        edge_index, edge_weight, x.size(self.node_dim), False,
+                        self.add_self_loops, dtype=x.dtype)
+                    if self.cached:
+                        self._cached_edge_index = (edge_index, edge_weight)
+                else:
+                    edge_index, edge_weight = cache[0], cache[1]
 
-        elif isinstance(edge_index, SparseTensor):
-            cache = self._cached_adj_t
-            if cache is None:
-                edge_index = gcn_norm(  # yapf: disable
-                    edge_index, edge_weight, x.size(self.node_dim), False,
-                    self.add_self_loops, dtype=x.dtype)
-                if self.cached:
-                    self._cached_adj_t = edge_index
-            else:
-                edge_index = cache
+            elif isinstance(edge_index, SparseTensor):
+                cache = self._cached_adj_t
+                if cache is None:
+                    edge_index = gcn_norm(  # yapf: disable
+                        edge_index, edge_weight, x.size(self.node_dim), False,
+                        self.add_self_loops, dtype=x.dtype)
+                    if self.cached:
+                        self._cached_adj_t = edge_index
+                else:
+                    edge_index = cache
 
         # propagate_type: (x: Tensor, edge_weight: OptTensor)
         return self.propagate(edge_index, x=x, edge_weight=edge_weight,
