@@ -5,7 +5,7 @@ import torch
 from torch import Tensor
 from torch.nn import Parameter
 from torch_scatter import scatter_add
-from torch_sparse import SparseTensor, matmul, fill_diag, sum, mul_
+from torch_sparse import SparseTensor, matmul, fill_diag, sum, mul
 from torch_geometric.nn.conv import MessagePassing
 from torch_geometric.utils import add_remaining_self_loops
 from torch_geometric.utils.num_nodes import maybe_num_nodes
@@ -35,14 +35,14 @@ def gcn_norm(edge_index, edge_weight=None, num_nodes=None, improved=False,
     if isinstance(edge_index, SparseTensor):
         adj_t = edge_index
         if not adj_t.has_value():
-            adj_t.fill_value(1., dtype=dtype)
+            adj_t = adj_t.fill_value(1., dtype=dtype)
         if add_self_loops:
             adj_t = fill_diag(adj_t, fill_value)
         deg = sum(adj_t, dim=1)
         deg_inv_sqrt = deg.pow_(-0.5)
         deg_inv_sqrt.masked_fill_(deg_inv_sqrt == float('inf'), 0.)
-        adj_t = mul_(adj_t, deg_inv_sqrt.view(-1, 1))
-        adj_t = mul_(adj_t, deg_inv_sqrt.view(1, -1))
+        adj_t = mul(adj_t, deg_inv_sqrt.view(-1, 1))
+        adj_t = mul(adj_t, deg_inv_sqrt.view(1, -1))
         return adj_t
 
     else:
@@ -77,6 +77,18 @@ class GCNConv(MessagePassing):
     where :math:`\mathbf{\hat{A}} = \mathbf{A} + \mathbf{I}` denotes the
     adjacency matrix with inserted self-loops and
     :math:`\hat{D}_{ii} = \sum_{j=0} \hat{A}_{ij}` its diagonal degree matrix.
+    The adjacency matrix can include other values than :obj:`1` representing
+    edge weights via the optional :obj:`edge_weight` tensor.
+
+    Its node-wise formulation is given by:
+
+    .. math::
+        \mathbf{x}^{\prime}_i = \mathbf{\Theta} \sum_{j}
+        \frac{1}{\sqrt{\hat{d}_j \hat{d}_i}} \mathbf{x}_j
+
+    with :math:`\hat{d}_i = 1 + \sum_{j \in \mathcal{N}(i)} e_{j,i}`, where
+    :math:`e_{j,i}` denotes the edge weight from source node :obj:`i` to target
+    node :obj:`j` (default: :obj:`1`)
 
     Args:
         in_channels (int): Size of each input sample.
@@ -90,10 +102,10 @@ class GCNConv(MessagePassing):
             cached version for further executions.
             This parameter should only be set to :obj:`True` in transductive
             learning scenarios. (default: :obj:`False`)
-        normalize (bool, optional): Whether to add self-loops and apply
-            symmetric normalization. (default: :obj:`True`)
         add_self_loops (bool, optional): If set to :obj:`False`, will not add
             self-loops to the input graph. (default: :obj:`True`)
+        normalize (bool, optional): Whether to add self-loops and apply
+            symmetric normalization. (default: :obj:`True`)
         bias (bool, optional): If set to :obj:`False`, the layer will not learn
             an additive bias. (default: :obj:`True`)
         **kwargs (optional): Additional arguments of
@@ -108,14 +120,15 @@ class GCNConv(MessagePassing):
                  add_self_loops: bool = True, normalize: bool = True,
                  bias: bool = True, **kwargs):
 
-        super(GCNConv, self).__init__(aggr='add', **kwargs)
+        kwargs.setdefault('aggr', 'add')
+        super(GCNConv, self).__init__(**kwargs)
 
         self.in_channels = in_channels
         self.out_channels = out_channels
         self.improved = improved
         self.cached = cached
-        self.normalize = normalize
         self.add_self_loops = add_self_loops
+        self.normalize = normalize
 
         self._cached_edge_index = None
         self._cached_adj_t = None
@@ -173,8 +186,11 @@ class GCNConv(MessagePassing):
 
         return out
 
-    def message(self, x_j: Tensor, edge_weight: Tensor) -> Tensor:
-        return edge_weight.view(-1, 1) * x_j
+    def message(self, x_j: Tensor, edge_weight: OptTensor) -> Tensor:
+        if edge_weight is None:
+            return x_j
+        else:
+            return edge_weight.view(-1, 1) * x_j
 
     def message_and_aggregate(self, adj_t: SparseTensor, x: Tensor) -> Tensor:
         return matmul(adj_t, x, reduce=self.aggr)
