@@ -33,7 +33,8 @@ class SAGEConv(MessagePassing):
     def __init__(self, in_channels: Union[int, Tuple[int, int]],
                  out_channels: int, normalize: bool = False,
                  bias: bool = True, **kwargs):  # yapf: disable
-        super(SAGEConv, self).__init__(aggr='mean', **kwargs)
+        kwargs.setdefault('aggr', 'mean')
+        super(SAGEConv, self).__init__(**kwargs)
 
         self.in_channels = in_channels
         self.out_channels = out_channels
