@@ -1,4 +1,6 @@
+from copy import copy
 from math import sqrt
+from typing import Optional
 
 import torch
 from tqdm import tqdm
@@ -30,22 +32,32 @@ class GNNExplainer(torch.nn.Module):
             (default: :obj:`100`)
         lr (float, optional): The learning rate to apply.
             (default: :obj:`0.01`)
+        num_hops (int, optional): The number of hops the :obj:`model` is
+            aggregating information from.
+            If set to :obj:`None`, will automatically try to detect this
+            information based on the number of
+            :class:`~torch_geometric.nn.conv.message_passing.MessagePassing`
+            layers inside :obj:`model`. (default: :obj:`None`)
         log (bool, optional): If set to :obj:`False`, will not log any learning
             progress. (default: :obj:`True`)
     """
 
     coeffs = {
         'edge_size': 0.005,
+        'edge_reduction': 'sum',
         'node_feat_size': 1.0,
+        'node_feat_reduction': 'mean',
         'edge_ent': 1.0,
         'node_feat_ent': 0.1,
     }
 
-    def __init__(self, model, epochs=100, lr=0.01, log=True):
+    def __init__(self, model, epochs: int = 100, lr: float = 0.01,
+                 num_hops: Optional[int] = None, log: bool = True):
         super(GNNExplainer, self).__init__()
         self.model = model
         self.epochs = epochs
         self.lr = lr
+        self.__num_hops__ = num_hops
         self.log = log
 
     def __set_masks__(self, x, edge_index, init="normal"):
@@ -70,12 +82,16 @@ class GNNExplainer(torch.nn.Module):
         self.node_feat_masks = None
         self.edge_mask = None
 
-    def __num_hops__(self):
-        num_hops = 0
+    @property
+    def num_hops(self):
+        if self.__num_hops__ is not None:
+            return self.__num_hops__
+
+        k = 0
         for module in self.model.modules():
             if isinstance(module, MessagePassing):
-                num_hops += 1
-        return num_hops
+                k += 1
+        return k
 
     def __flow__(self):
         for module in self.model.modules():
@@ -87,7 +103,7 @@ class GNNExplainer(torch.nn.Module):
         num_nodes, num_edges = x.size(0), edge_index.size(1)
 
         subset, edge_index, mapping, edge_mask = k_hop_subgraph(
-            node_idx, self.__num_hops__(), edge_index, relabel_nodes=True,
+            node_idx, self.num_hops, edge_index, relabel_nodes=True,
             num_nodes=num_nodes, flow=self.__flow__())
 
         x = x[subset]
@@ -104,12 +120,14 @@ class GNNExplainer(torch.nn.Module):
         loss = -log_logits[node_idx, pred_label[node_idx]]
 
         m = self.edge_mask.sigmoid()
-        loss = loss + self.coeffs['edge_size'] * m.sum()
+        edge_reduce = getattr(torch, self.coeffs['edge_reduction'])
+        loss = loss + self.coeffs['edge_size'] * edge_reduce(m)
         ent = -m * torch.log(m + EPS) - (1 - m) * torch.log(1 - m + EPS)
         loss = loss + self.coeffs['edge_ent'] * ent.mean()
 
         m = self.node_feat_mask.sigmoid()
-        loss = loss + self.coeffs['node_feat_size'] * m.sum()
+        node_feat_reduce = getattr(torch, self.coeffs['node_feat_reduction'])
+        loss = loss + self.coeffs['node_feat_size'] * node_feat_reduce(m)
         ent = -m * torch.log(m + EPS) - (1 - m) * torch.log(1 - m + EPS)
         loss = loss + self.coeffs['node_feat_ent'] * ent.mean()
 
@@ -200,7 +218,7 @@ class GNNExplainer(torch.nn.Module):
 
         # Only operate on a k-hop subgraph around `node_idx`.
         subset, edge_index, _, hard_edge_mask = k_hop_subgraph(
-            node_idx, self.__num_hops__(), edge_index, relabel_nodes=True,
+            node_idx, self.num_hops, edge_index, relabel_nodes=True,
             num_nodes=None, flow=self.__flow__())
 
         edge_mask = edge_mask[hard_edge_mask]
@@ -220,10 +238,12 @@ class GNNExplainer(torch.nn.Module):
         mapping = {k: i for k, i in enumerate(subset.tolist())}
         G = nx.relabel_nodes(G, mapping)
 
-        kwargs['with_labels'] = kwargs.get('with_labels') or True
-        kwargs['font_size'] = kwargs.get('font_size') or 10
-        kwargs['node_size'] = kwargs.get('node_size') or 800
-        kwargs['cmap'] = kwargs.get('cmap') or 'cool'
+        node_kwargs = copy(kwargs)
+        node_kwargs['node_size'] = kwargs.get('node_size') or 800
+        node_kwargs['cmap'] = kwargs.get('cmap') or 'cool'
+
+        label_kwargs = copy(kwargs)
+        label_kwargs['font_size'] = kwargs.get('font_size') or 10
 
         pos = nx.spring_layout(G)
         ax = plt.gca()
@@ -233,12 +253,12 @@ class GNNExplainer(torch.nn.Module):
                 textcoords='data', arrowprops=dict(
                     arrowstyle="->",
                     alpha=max(data['att'], 0.1),
-                    shrinkA=sqrt(kwargs['node_size']) / 2.0,
-                    shrinkB=sqrt(kwargs['node_size']) / 2.0,
+                    shrinkA=sqrt(node_kwargs['node_size']) / 2.0,
+                    shrinkB=sqrt(node_kwargs['node_size']) / 2.0,
                     connectionstyle="arc3,rad=0.1",
                 ))
-        nx.draw_networkx_nodes(G, pos, node_color=y.tolist(), **kwargs)
-        nx.draw_networkx_labels(G, pos, **kwargs)
+        nx.draw_networkx_nodes(G, pos, node_color=y.tolist(), **node_kwargs)
+        nx.draw_networkx_labels(G, pos, **label_kwargs)
 
         return ax, G
 
