@@ -1,5 +1,6 @@
 from .compose import Compose
 from .to_sparse_tensor import ToSparseTensor
+from .to_undirected import ToUndirected
 from .constant import Constant
 from .distance import Distance
 from .cartesian import Cartesian
@@ -37,10 +38,12 @@ from .to_superpixels import ToSLIC
 from .gdc import GDC
 from .sign import SIGN
 from .grid_sampling import GridSampling
+from .gcn_norm import GCNNorm
 
 __all__ = [
     'Compose',
     'ToSparseTensor',
+    'ToUndirected',
     'Constant',
     'Distance',
     'Cartesian',
@@ -78,4 +81,7 @@ __all__ = [
     'GDC',
     'SIGN',
     'GridSampling',
+    'GCNNorm',
 ]
+
+classes = __all__
