@@ -1,12 +1,14 @@
 from typing import Optional
 
+import torch
 from torch import Tensor
 from torch_scatter import scatter, segment_csr, gather_csr
 
 from .num_nodes import maybe_num_nodes
 
 
-def softmax(src: Tensor, index: Tensor, ptr: Optional[Tensor] = None,
+@torch.jit.script
+def softmax(src: Tensor, index: Optional[Tensor], ptr: Optional[Tensor] = None,
             num_nodes: Optional[int] = None) -> Tensor:
     r"""Computes a sparsely evaluated softmax.
     Given a value tensor :attr:`src`, this function first groups the values
@@ -23,15 +25,15 @@ def softmax(src: Tensor, index: Tensor, ptr: Optional[Tensor] = None,
 
     :rtype: :class:`Tensor`
     """
+    out = src - src.max()
+    out = out.exp()
 
-    if ptr is None:
-        N = maybe_num_nodes(index, num_nodes)
-        out = src - scatter(src, index, dim=0, dim_size=N, reduce='max')[index]
-        out = out.exp()
-        out_sum = scatter(out, index, dim=0, dim_size=N, reduce='sum')[index]
-        return out / (out_sum + 1e-16)
-    else:
-        out = src - gather_csr(segment_csr(src, ptr, reduce='max'), ptr)
-        out = out.exp()
+    if ptr is not None:
         out_sum = gather_csr(segment_csr(out, ptr, reduce='sum'), ptr)
-        return out / (out_sum + 1e-16)
+    elif index is not None:
+        N = maybe_num_nodes(index, num_nodes)
+        out_sum = scatter(out, index, dim=0, dim_size=N, reduce='sum')[index]
+    else:
+        raise NotImplementedError
+
+    return out / (out_sum + 1e-16)
